{% extends "base.html" %}

{% block title %}{{ page.title }} | {{ config.title }}{% endblock title %}

{% block content %}
<div class="page-content">
    <h1 class="page-content__title">{{ page.title }}</h1>
    <div class="page-content__body">{{ page.content | safe }}</div>
</div>
{% endblock content %}
